@@ -1,5 +1,16 @@
+# 
+# This file is part of HTML-FormFu-ExtJS
+# 
+# This software is Copyright (c) 2010 by Moritz Onken.
+# 
+# This is free software, licensed under:
+# 
+#   The (three-clause) BSD License
+# 
 package HTML::FormFu::ExtJS::Element::ComboBox;
-our $VERSION = '0.075';
+BEGIN {
+  $HTML::FormFu::ExtJS::Element::ComboBox::VERSION = '0.076';
+}
 
 use base "HTML::FormFu::ExtJS::Element::Select";
 
@@ -34,13 +45,17 @@ sub render {
 
 1;
 
+
+__END__
+=pod
+
 =head1 NAME
 
-HTML::FormFu::ExtJS::Element::ComboBox - An editable select box
+HTML::FormFu::ExtJS::Element::ComboBox
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 DESCRIPTION
 
@@ -58,6 +73,9 @@ The default ExtJS setup is:
   "store"          : new Ext.data.SimpleStore( ... ),
   "xtype"          : "combo"
 
+=head1 NAME
+
+HTML::FormFu::ExtJS::Element::ComboBox - An editable select box
 
 =head1 SEE ALSO
 
@@ -70,5 +88,17 @@ Copyright 2009 Moritz Onken, all rights reserved.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+  Moritz Onken <onken@netcubed.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Moritz Onken.
+
+This is free software, licensed under:
+
+  The (three-clause) BSD License
+
+=cut
 
-=cut
\ No newline at end of file
