@@ -1,5 +1,16 @@
+# 
+# This file is part of HTML-FormFu-ExtJS
+# 
+# This software is Copyright (c) 2010 by Moritz Onken.
+# 
+# This is free software, licensed under:
+# 
+#   The (three-clause) BSD License
+# 
 package HTML::FormFu::ExtJS::Element::DateTime;
-our $VERSION = '0.075';
+BEGIN {
+  $HTML::FormFu::ExtJS::Element::DateTime::VERSION = '0.076';
+}
 use base "HTML::FormFu::ExtJS::Element::_Field";
 
 use HTML::FormFu::ExtJS::Element::Select;
@@ -55,15 +66,17 @@ sub column_model {
 
 1; 
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-HTML::FormFu::ExtJS::Element::DateTime - DateTime element
+HTML::FormFu::ExtJS::Element::DateTime
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 DESCRIPTION
 
@@ -76,6 +89,9 @@ The date parsing and format syntax is a subset of PHP's date() function.
 See L<http://extjs.com/deploy/dev/docs/?class=Date> for details.
 It defaults to C<Y-m-d G:i> (which is the same as Perl's C<%Y-%m-%d %R>).
 
+=head1 NAME
+
+HTML::FormFu::ExtJS::Element::DateTime - DateTime element
 
 =head1 SEE ALSO
 
@@ -88,5 +104,22 @@ Copyright 2009 Moritz Onken, all rights reserved.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=cut
+
+=head1 AUTHOR
+
+  Moritz Onken <onken@netcubed.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Moritz Onken.
+
+This is free software, licensed under:
+
+  The (three-clause) BSD License
+
+=cut
+
+
+__END__
 
-=cut
\ No newline at end of file
