@@ -1,5 +1,16 @@
+# 
+# This file is part of HTML-FormFu-ExtJS
+# 
+# This software is Copyright (c) 2010 by Moritz Onken.
+# 
+# This is free software, licensed under:
+# 
+#   The (three-clause) BSD License
+# 
 package HTML::FormFu::ExtJS::Element::Radio;
-our $VERSION = '0.075';
+BEGIN {
+  $HTML::FormFu::ExtJS::Element::Radio::VERSION = '0.076';
+}
 use base "HTML::FormFu::ExtJS::Element::_Field";
 
 use strict;
@@ -20,18 +31,26 @@ sub render {
 }
 1;
 
+
+__END__
+=pod
+
 =head1 NAME
 
-HTML::FormFu::ExtJS::Element::Radio - Radio element
+HTML::FormFu::ExtJS::Element::Radio
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 DESCRIPTION
 
 Simple Radio element.
 
+=head1 NAME
+
+HTML::FormFu::ExtJS::Element::Radio - Radio element
+
 =head1 SEE ALSO
 
 L<HTML::FormFu::Element::Radio>
@@ -43,5 +62,17 @@ Copyright 2008 Moritz Onken, all rights reserved.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+  Moritz Onken <onken@netcubed.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Moritz Onken.
+
+This is free software, licensed under:
+
+  The (three-clause) BSD License
+
+=cut
 
-=cut
\ No newline at end of file
