@@ -1,5 +1,16 @@
+# 
+# This file is part of HTML-FormFu-ExtJS
+# 
+# This software is Copyright (c) 2010 by Moritz Onken.
+# 
+# This is free software, licensed under:
+# 
+#   The (three-clause) BSD License
+# 
 package HTML::FormFu::ExtJS::Element::SimpleTable;
-our $VERSION = '0.075';
+BEGIN {
+  $HTML::FormFu::ExtJS::Element::SimpleTable::VERSION = '0.076';
+}
 
 use strict;
 use warnings;
@@ -47,13 +58,17 @@ sub render {
 1;
 
 
+
+__END__
+=pod
+
 =head1 NAME
 
-HTML::FormFu::ExtJS::Element::SimpleTable - Simple table layout
+HTML::FormFu::ExtJS::Element::SimpleTable
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 DESCRIPTION
 
@@ -62,6 +77,10 @@ way to influence the width etc. of each column. They get distributed equally.
 
 To create layouts with individual width and styles see L<HTML::FormFu::ExtJS::Element::Multi>.
 
+=head1 NAME
+
+HTML::FormFu::ExtJS::Element::SimpleTable - Simple table layout
+
 =head1 SEE ALSO
 
 L<HTML::FormFu::Element::Multi>
@@ -73,5 +92,17 @@ Copyright 2008 Moritz Onken, all rights reserved.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+  Moritz Onken <onken@netcubed.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Moritz Onken.
+
+This is free software, licensed under:
+
+  The (three-clause) BSD License
+
+=cut
 
-=cut
\ No newline at end of file
