@@ -1,5 +1,16 @@
+# 
+# This file is part of HTML-FormFu-ExtJS
+# 
+# This software is Copyright (c) 2010 by Moritz Onken.
+# 
+# This is free software, licensed under:
+# 
+#   The (three-clause) BSD License
+# 
 package HTML::FormFu::ExtJS::Element::Textarea;
-our $VERSION = '0.075';
+BEGIN {
+  $HTML::FormFu::ExtJS::Element::Textarea::VERSION = '0.076';
+}
 
 use base "HTML::FormFu::ExtJS::Element::_Field";
 
@@ -21,13 +32,17 @@ sub render {
 
 1;
 
+
+__END__
+=pod
+
 =head1 NAME
 
-HTML::FormFu::ExtJS::Element::Textarea - Textarea element
+HTML::FormFu::ExtJS::Element::Textarea
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 DESCRIPTION
 
@@ -39,7 +54,9 @@ You can either use the standard html textarea element or use the ExtJS WYSIWYG e
     attrs_xml:
       wysiwyg: 1
 
+=head1 NAME
 
+HTML::FormFu::ExtJS::Element::Textarea - Textarea element
 
 =head1 SEE ALSO
 
@@ -52,5 +69,19 @@ Copyright 2008 Moritz Onken, all rights reserved.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=cut
+
+=head1 AUTHOR
+
+  Moritz Onken <onken@netcubed.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Moritz Onken.
+
+This is free software, licensed under:
+
+  The (three-clause) BSD License
+
+=cut
 
-=cut
\ No newline at end of file
