@@ -1,5 +1,16 @@
+# 
+# This file is part of HTML-FormFu-ExtJS
+# 
+# This software is Copyright (c) 2010 by Moritz Onken.
+# 
+# This is free software, licensed under:
+# 
+#   The (three-clause) BSD License
+# 
 package HTML::FormFu::ExtJS::Element::_Group;
-our $VERSION = '0.075';
+BEGIN {
+  $HTML::FormFu::ExtJS::Element::_Group::VERSION = '0.076';
+}
 
 use base "HTML::FormFu::ExtJS::Element::_Field";
 
@@ -83,4 +94,29 @@ sub record {
 
 
 
-1;
\ No newline at end of file
+1;
+__END__
+=pod
+
+=head1 NAME
+
+HTML::FormFu::ExtJS::Element::_Group
+
+=head1 VERSION
+
+version 0.076
+
+=head1 AUTHOR
+
+  Moritz Onken <onken@netcubed.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Moritz Onken.
+
+This is free software, licensed under:
+
+  The (three-clause) BSD License
+
+=cut
+
